@@ -383,7 +383,7 @@ TranslucentButton::TranslucentButton(wxWindow *parent, wxWindowID winid, const w
 {
     wxButton::Create(parent, winid, label);
 #ifdef __WXMSW__
-    if (IsWindows10OrGreater())
+    if (IsWindows10OrGreater() && ColorScheme::GetAppMode() != ColorScheme::Dark)
         SetBackgroundColour(ColorScheme::GetBlendedOn(::Color::TranslucentButton, parent));
 #endif
 }
