@@ -432,3 +432,15 @@ void ActivityIndicator::StopWithError(const wxString& msg)
 
     UpdateLayoutAfterTextChange();
 }
+
+
+
+ImageButton::ImageButton(wxWindow *parent, const wxBitmap& bmp)
+    : wxBitmapButton(parent, wxID_ANY, bmp, wxDefaultPosition, wxDefaultSize, wxBORDER_NONE | wxBU_EXACTFIT)
+{
+#ifdef __WXOSX__
+    // don't light up the background when clicked:
+    NSButton *view = (NSButton*)GetHandle();
+    view.buttonType = NSMomentaryChangeButton;
+#endif
+}
