@@ -29,7 +29,13 @@
 
 #include <set>
 
+#ifdef __WXGTK__
+#include <gtk/gtk.h>
+#endif
+
 #include "icons.h"
+
+#include "colorscheme.h"
 #include "edapp.h"
 #include "hidpi.h"
 #include "utility.h"
@@ -87,8 +93,49 @@ bool ShouldBeMirorredInRTL(const wxArtID& id, const wxArtClient& client)
     return mirror;
 }
 
+void ProcessTemplateImage(wxImage& img, bool keepOpaque, bool inverted)
+{
+    int size = img.GetWidth() * img.GetHeight();
+
+    ColorScheme::Mode inverseMode = inverted ? ColorScheme::Light : ColorScheme::Dark;
+    if (ColorScheme::GetAppMode() == inverseMode)
+    {
+        auto rgb = img.GetData();
+        for (int i = 0; i < 3*size; ++i, ++rgb)
+            *rgb = 255 - *rgb;
+    }
+
+    // Apply 50% transparency
+    if (!keepOpaque)
+    {
+        auto alpha = img.GetAlpha();
+        for (int i = 0; i < size; ++i, ++alpha)
+            *alpha /= 2;
+    }
+}
+
 } // anonymous namespace
 
+
+
+PoeditArtProvider::PoeditArtProvider()
+{
+#ifdef __WXGTK3__
+    gtk_icon_theme_prepend_search_path(gtk_icon_theme_get_default(), GetIconsDir().fn_str());
+#endif
+}
+
+
+wxString PoeditArtProvider::GetIconsDir()
+{
+#if defined(__WXMSW__)
+    return wxStandardPaths::Get().GetResourcesDir() + "\\Resources";
+#else
+    return wxStandardPaths::Get().GetInstallPrefix() + "/share/poedit/icons";
+#endif
+}
+
+
 wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
                                          const wxArtClient& client,
                                          const wxSize& size)
@@ -96,9 +143,13 @@ wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
     wxLogTrace("poedit.icons", "getting icon '%s'", id_.c_str());
 
     wxArtID id(id_);
-    const bool disabledVariant = id.Contains("@disabled");
-    if (disabledVariant)
-        id.Replace("@disabled", "");
+    #define CHECK_FOR_VARIANT(name)                         \
+        const bool name##Variant = id.Contains("@" #name);  \
+        if (name##Variant)                                  \
+            id.Replace("@" #name, "")
+    CHECK_FOR_VARIANT(disabled);
+    CHECK_FOR_VARIANT(opaque);
+    CHECK_FOR_VARIANT(inverted);
 
     // Silence warning about unused parameter in some of the builds
     (void)client;
@@ -120,12 +171,7 @@ wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
     }
 #endif // __WXGTK20__
 
-    wxString iconsdir =
-#if defined(__WXMSW__)
-        wxStandardPaths::Get().GetResourcesDir() + "\\Resources";
-#else
-        wxStandardPaths::Get().GetInstallPrefix() + "/share/poedit/icons";
-#endif
+    auto iconsdir = GetIconsDir();
     if ( !wxDirExists(iconsdir) )
     {
         wxLogTrace("poedit.icons",
@@ -136,13 +182,21 @@ wxBitmap PoeditArtProvider::CreateBitmap(const wxArtID& id_,
     wxString icon;
     icon.Printf("%s/%s", iconsdir, id);
     wxLogTrace("poedit.icons", "loading from %s", icon);
-    wxImage img = LoadScaledBitmap(icon);
+    wxImage img;
+    if (ColorScheme::GetAppMode() == ColorScheme::Dark)
+        img = LoadScaledBitmap(icon + "Dark");
+    if (!img.IsOk())
+        img = LoadScaledBitmap(icon);
+
     if (!img.IsOk())
     {
         wxLogTrace("poedit.icons", "failed to load icon '%s'", id);
         return wxNullBitmap;
     }
 
+    if (id.EndsWith("Template"))
+        ProcessTemplateImage(img, opaqueVariant, invertedVariant);
+
     if (disabledVariant)
         img = img.ConvertToDisabled();
 
