@@ -68,6 +68,11 @@ inline std::wstring to_wstring(const std::string& utf8str)
     return boost::locale::conv::utf_to_utf<wchar_t>(utf8str);
 }
 
+inline std::wstring to_wstring(const char *utf8str)
+{
+    return boost::locale::conv::utf_to_utf<wchar_t>(utf8str);
+}
+
 inline std::string to_utf8(const wxString& str)
 {
     return std::string(str.utf8_str());
@@ -78,6 +83,16 @@ inline std::wstring to_wstring(const wxString& str)
     return str.ToStdWstring();
 }
 
+inline wxString to_wx(const char *utf8)
+{
+    return wxString::FromUTF8(utf8);
+}
+
+inline wxString to_wx(const std::string& utf8)
+{
+    return wxString::FromUTF8(utf8.c_str());
+}
+
 #if defined(__cplusplus) && defined(__OBJC__)
 
 inline NSString *to_NS(const wxString& str)
