@@ -191,6 +191,17 @@ inline wxFileName CommonDirectory(const T& a)
 }
 
 
+inline wxString MaskForType(const char *extensions, const wxString& description, bool showExt = true)
+{
+    (void)showExt;
+#ifdef __WXMSW__
+    if (showExt)
+        return wxString::Format("%s (%s)|%s", description, extensions, extensions);
+    else
+#endif
+        return wxString::Format("%s|%s", description, extensions);
+}
+
 
 // ----------------------------------------------------------------------
 // TempDirectory
